All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08
@ 2023-01-05  1:04 Aaron Liu
  2023-01-05  1:04 ` [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd Aaron Liu
  2023-01-05  1:38 ` [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Liu, HaoPing (Alan)
  0 siblings, 2 replies; 6+ messages in thread
From: Aaron Liu @ 2023-01-05  1:04 UTC (permalink / raw)
  To: amd-gfx; +Cc: haoping.liu, Alexander.Deucher, shane.xiao, Aaron Liu

1. Rename securedisplay_cmd to ta_securedisplay_cmd.
2. Rename ta_securedisplay_max_phy to ta_securedisplay_phy_ID.

Signed-off-by: Aaron Liu <aaron.liu@amd.com>
Signed-off-by: Shane Xiao <shane.xiao@amd.com>
---
 .../gpu/drm/amd/amdgpu/ta_secureDisplay_if.h  | 24 +++++++++----------
 1 file changed, 12 insertions(+), 12 deletions(-)

-- 
2.39.0


^ permalink raw reply related	[flat|nested] 6+ messages in thread

* [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd
  2023-01-05  1:04 [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Aaron Liu
@ 2023-01-05  1:04 ` Aaron Liu
  2023-01-05  1:38   ` Liu, HaoPing (Alan)
  2023-01-05  3:27   ` Alex Deucher
  2023-01-05  1:38 ` [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Liu, HaoPing (Alan)
  1 sibling, 2 replies; 6+ messages in thread
From: Aaron Liu @ 2023-01-05  1:04 UTC (permalink / raw)
  To: amd-gfx; +Cc: haoping.liu, Alexander.Deucher, shane.xiao, Aaron Liu

This patch updates securedisplay_cmd to ta_securedisplay_cmd
starting from amd-ta_securedisplay-v27.00.00.08.

Signed-off-by: Aaron Liu <aaron.liu@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c               | 2 +-
 drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c     | 8 ++++----
 drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h     | 2 +-
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c | 2 +-
 4 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
index 0706afb11577..2bebda7de604 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
@@ -1907,7 +1907,7 @@ int psp_rap_invoke(struct psp_context *psp, uint32_t ta_cmd_id, enum ta_rap_stat
 static int psp_securedisplay_initialize(struct psp_context *psp)
 {
 	int ret;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 
 	/*
 	 * TODO: bypass the initialize in sriov for now
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
index 2c1d82fc4c34..8ed0e073656f 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
@@ -77,11 +77,11 @@ void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 	}
 }
 
-void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
 	enum ta_securedisplay_command command_id)
 {
-	*cmd = (struct securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
-	memset(*cmd, 0, sizeof(struct securedisplay_cmd));
+	*cmd = (struct ta_securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
+	memset(*cmd, 0, sizeof(struct ta_securedisplay_cmd));
 	(*cmd)->status = TA_SECUREDISPLAY_STATUS__GENERIC_FAILURE;
 	(*cmd)->cmd_id = command_id;
 }
@@ -93,7 +93,7 @@ static ssize_t amdgpu_securedisplay_debugfs_write(struct file *f, const char __u
 {
 	struct amdgpu_device *adev = (struct amdgpu_device *)file_inode(f)->i_private;
 	struct psp_context *psp = &adev->psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_device *dev = adev_to_drm(adev);
 	uint32_t phy_id;
 	uint32_t op;
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
index fe98574748f4..456ad68ed4b2 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
@@ -30,7 +30,7 @@
 void amdgpu_securedisplay_debugfs_init(struct amdgpu_device *adev);
 void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 		enum ta_securedisplay_status status);
-void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
 		enum ta_securedisplay_command command_id);
 
 #endif
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
index ad73e5855580..8841c447d0e2 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
@@ -103,7 +103,7 @@ static void amdgpu_dm_crtc_notify_ta_to_read(struct work_struct *work)
 {
 	struct secure_display_context *secure_display_ctx;
 	struct psp_context *psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_crtc *crtc;
 	struct dc_stream_state *stream;
 	uint8_t phy_inst;
-- 
2.39.0

^ permalink raw reply related	[flat|nested] 6+ messages in thread

* RE: [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd
  2023-01-05  1:04 ` [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd Aaron Liu
@ 2023-01-05  1:38   ` Liu, HaoPing (Alan)
  2023-01-05  3:27   ` Alex Deucher
  1 sibling, 0 replies; 6+ messages in thread
From: Liu, HaoPing (Alan) @ 2023-01-05  1:38 UTC (permalink / raw)
  To: Liu, Aaron, amd-gfx; +Cc: Deucher, Alexander, Xiao, Shane

[AMD Official Use Only - General]

Reviewed-by: Alan Liu <HaoPing.Liu@amd.com>

-----Original Message-----
From: Liu, Aaron <Aaron.Liu@amd.com> 
Sent: Thursday, January 5, 2023 9:04 AM
To: amd-gfx@lists.freedesktop.org
Cc: Liu, HaoPing (Alan) <HaoPing.Liu@amd.com>; Deucher, Alexander <Alexander.Deucher@amd.com>; Xiao, Shane <shane.xiao@amd.com>; Liu, Aaron <Aaron.Liu@amd.com>
Subject: [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd

This patch updates securedisplay_cmd to ta_securedisplay_cmd starting from amd-ta_securedisplay-v27.00.00.08.

Signed-off-by: Aaron Liu <aaron.liu@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c               | 2 +-
 drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c     | 8 ++++----
 drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h     | 2 +-
 drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c | 2 +-
 4 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
index 0706afb11577..2bebda7de604 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
@@ -1907,7 +1907,7 @@ int psp_rap_invoke(struct psp_context *psp, uint32_t ta_cmd_id, enum ta_rap_stat  static int psp_securedisplay_initialize(struct psp_context *psp)  {
 	int ret;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 
 	/*
 	 * TODO: bypass the initialize in sriov for now diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
index 2c1d82fc4c34..8ed0e073656f 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
@@ -77,11 +77,11 @@ void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 	}
 }
 
-void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct 
+ta_securedisplay_cmd **cmd,
 	enum ta_securedisplay_command command_id)  {
-	*cmd = (struct securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
-	memset(*cmd, 0, sizeof(struct securedisplay_cmd));
+	*cmd = (struct ta_securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
+	memset(*cmd, 0, sizeof(struct ta_securedisplay_cmd));
 	(*cmd)->status = TA_SECUREDISPLAY_STATUS__GENERIC_FAILURE;
 	(*cmd)->cmd_id = command_id;
 }
@@ -93,7 +93,7 @@ static ssize_t amdgpu_securedisplay_debugfs_write(struct file *f, const char __u  {
 	struct amdgpu_device *adev = (struct amdgpu_device *)file_inode(f)->i_private;
 	struct psp_context *psp = &adev->psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_device *dev = adev_to_drm(adev);
 	uint32_t phy_id;
 	uint32_t op;
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
index fe98574748f4..456ad68ed4b2 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
@@ -30,7 +30,7 @@
 void amdgpu_securedisplay_debugfs_init(struct amdgpu_device *adev);  void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 		enum ta_securedisplay_status status); -void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct 
+ta_securedisplay_cmd **cmd,
 		enum ta_securedisplay_command command_id);
 
 #endif
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
index ad73e5855580..8841c447d0e2 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
@@ -103,7 +103,7 @@ static void amdgpu_dm_crtc_notify_ta_to_read(struct work_struct *work)  {
 	struct secure_display_context *secure_display_ctx;
 	struct psp_context *psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_crtc *crtc;
 	struct dc_stream_state *stream;
 	uint8_t phy_inst;
--
2.39.0

^ permalink raw reply related	[flat|nested] 6+ messages in thread

* Re: [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd
  2023-01-05  1:04 ` [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd Aaron Liu
  2023-01-05  1:38   ` Liu, HaoPing (Alan)
@ 2023-01-05  3:27   ` Alex Deucher
  2023-01-05  4:59     ` Liu, Aaron
  1 sibling, 1 reply; 6+ messages in thread
From: Alex Deucher @ 2023-01-05  3:27 UTC (permalink / raw)
  To: Aaron Liu; +Cc: haoping.liu, Alexander.Deucher, shane.xiao, amd-gfx

These two patches should be squashed together to avoid breaking the build.

Alex

On Wed, Jan 4, 2023 at 8:04 PM Aaron Liu <aaron.liu@amd.com> wrote:
>
> This patch updates securedisplay_cmd to ta_securedisplay_cmd
> starting from amd-ta_securedisplay-v27.00.00.08.
>
> Signed-off-by: Aaron Liu <aaron.liu@amd.com>
> ---
>  drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c               | 2 +-
>  drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c     | 8 ++++----
>  drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h     | 2 +-
>  drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c | 2 +-
>  4 files changed, 7 insertions(+), 7 deletions(-)
>
> diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> index 0706afb11577..2bebda7de604 100644
> --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> @@ -1907,7 +1907,7 @@ int psp_rap_invoke(struct psp_context *psp, uint32_t ta_cmd_id, enum ta_rap_stat
>  static int psp_securedisplay_initialize(struct psp_context *psp)
>  {
>         int ret;
> -       struct securedisplay_cmd *securedisplay_cmd;
> +       struct ta_securedisplay_cmd *securedisplay_cmd;
>
>         /*
>          * TODO: bypass the initialize in sriov for now
> diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> index 2c1d82fc4c34..8ed0e073656f 100644
> --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> @@ -77,11 +77,11 @@ void psp_securedisplay_parse_resp_status(struct psp_context *psp,
>         }
>  }
>
> -void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
> +void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
>         enum ta_securedisplay_command command_id)
>  {
> -       *cmd = (struct securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
> -       memset(*cmd, 0, sizeof(struct securedisplay_cmd));
> +       *cmd = (struct ta_securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
> +       memset(*cmd, 0, sizeof(struct ta_securedisplay_cmd));
>         (*cmd)->status = TA_SECUREDISPLAY_STATUS__GENERIC_FAILURE;
>         (*cmd)->cmd_id = command_id;
>  }
> @@ -93,7 +93,7 @@ static ssize_t amdgpu_securedisplay_debugfs_write(struct file *f, const char __u
>  {
>         struct amdgpu_device *adev = (struct amdgpu_device *)file_inode(f)->i_private;
>         struct psp_context *psp = &adev->psp;
> -       struct securedisplay_cmd *securedisplay_cmd;
> +       struct ta_securedisplay_cmd *securedisplay_cmd;
>         struct drm_device *dev = adev_to_drm(adev);
>         uint32_t phy_id;
>         uint32_t op;
> diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> index fe98574748f4..456ad68ed4b2 100644
> --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> @@ -30,7 +30,7 @@
>  void amdgpu_securedisplay_debugfs_init(struct amdgpu_device *adev);
>  void psp_securedisplay_parse_resp_status(struct psp_context *psp,
>                 enum ta_securedisplay_status status);
> -void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
> +void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
>                 enum ta_securedisplay_command command_id);
>
>  #endif
> diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> index ad73e5855580..8841c447d0e2 100644
> --- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> +++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> @@ -103,7 +103,7 @@ static void amdgpu_dm_crtc_notify_ta_to_read(struct work_struct *work)
>  {
>         struct secure_display_context *secure_display_ctx;
>         struct psp_context *psp;
> -       struct securedisplay_cmd *securedisplay_cmd;
> +       struct ta_securedisplay_cmd *securedisplay_cmd;
>         struct drm_crtc *crtc;
>         struct dc_stream_state *stream;
>         uint8_t phy_inst;
> --
> 2.39.0
>

^ permalink raw reply	[flat|nested] 6+ messages in thread

* RE: [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd
  2023-01-05  3:27   ` Alex Deucher
@ 2023-01-05  4:59     ` Liu, Aaron
  0 siblings, 0 replies; 6+ messages in thread
From: Liu, Aaron @ 2023-01-05  4:59 UTC (permalink / raw)
  To: Alex Deucher
  Cc: Liu, HaoPing (Alan), Deucher, Alexander, Xiao, Shane, amd-gfx

[-- Attachment #1: Type: text/plain, Size: 5085 bytes --]

[AMD Official Use Only - General]

Squashed into one patch now.
Thanks Alex.

> -----Original Message-----
> From: Alex Deucher <alexdeucher@gmail.com>
> Sent: Thursday, January 5, 2023 11:28 AM
> To: Liu, Aaron <Aaron.Liu@amd.com>
> Cc: amd-gfx@lists.freedesktop.org; Liu, HaoPing (Alan)
> <HaoPing.Liu@amd.com>; Deucher, Alexander <Alexander.Deucher@amd.com>;
> Xiao, Shane <shane.xiao@amd.com>
> Subject: Re: [PATCH 2/2] drm/amd: update securedisplay_cmd to
> ta_securedisplay_cmd
>
> These two patches should be squashed together to avoid breaking the build.
>
> Alex
>
> On Wed, Jan 4, 2023 at 8:04 PM Aaron Liu <aaron.liu@amd.com> wrote:
> >
> > This patch updates securedisplay_cmd to ta_securedisplay_cmd starting
> > from amd-ta_securedisplay-v27.00.00.08.
> >
> > Signed-off-by: Aaron Liu <aaron.liu@amd.com>
> > ---
> >  drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c               | 2 +-
> >  drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c     | 8 ++++----
> >  drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h     | 2 +-
> >  drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c | 2 +-
> >  4 files changed, 7 insertions(+), 7 deletions(-)
> >
> > diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> > b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> > index 0706afb11577..2bebda7de604 100644
> > --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> > +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
> > @@ -1907,7 +1907,7 @@ int psp_rap_invoke(struct psp_context *psp,
> > uint32_t ta_cmd_id, enum ta_rap_stat  static int
> > psp_securedisplay_initialize(struct psp_context *psp)  {
> >         int ret;
> > -       struct securedisplay_cmd *securedisplay_cmd;
> > +       struct ta_securedisplay_cmd *securedisplay_cmd;
> >
> >         /*
> >          * TODO: bypass the initialize in sriov for now diff --git
> > a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> > b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> > index 2c1d82fc4c34..8ed0e073656f 100644
> > --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> > +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
> > @@ -77,11 +77,11 @@ void psp_securedisplay_parse_resp_status(struct
> psp_context *psp,
> >         }
> >  }
> >
> > -void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct
> > securedisplay_cmd **cmd,
> > +void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct
> > +ta_securedisplay_cmd **cmd,
> >         enum ta_securedisplay_command command_id)  {
> > -       *cmd = (struct securedisplay_cmd *)psp-
> >securedisplay_context.context.mem_context.shared_buf;
> > -       memset(*cmd, 0, sizeof(struct securedisplay_cmd));
> > +       *cmd = (struct ta_securedisplay_cmd *)psp-
> >securedisplay_context.context.mem_context.shared_buf;
> > +       memset(*cmd, 0, sizeof(struct ta_securedisplay_cmd));
> >         (*cmd)->status = TA_SECUREDISPLAY_STATUS__GENERIC_FAILURE;
> >         (*cmd)->cmd_id = command_id;
> >  }
> > @@ -93,7 +93,7 @@ static ssize_t
> > amdgpu_securedisplay_debugfs_write(struct file *f, const char __u  {
> >         struct amdgpu_device *adev = (struct amdgpu_device *)file_inode(f)-
> >i_private;
> >         struct psp_context *psp = &adev->psp;
> > -       struct securedisplay_cmd *securedisplay_cmd;
> > +       struct ta_securedisplay_cmd *securedisplay_cmd;
> >         struct drm_device *dev = adev_to_drm(adev);
> >         uint32_t phy_id;
> >         uint32_t op;
> > diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> > b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> > index fe98574748f4..456ad68ed4b2 100644
> > --- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> > +++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
> > @@ -30,7 +30,7 @@
> >  void amdgpu_securedisplay_debugfs_init(struct amdgpu_device *adev);
> > void psp_securedisplay_parse_resp_status(struct psp_context *psp,
> >                 enum ta_securedisplay_status status); -void
> > psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct
> > securedisplay_cmd **cmd,
> > +void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct
> > +ta_securedisplay_cmd **cmd,
> >                 enum ta_securedisplay_command command_id);
> >
> >  #endif
> > diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> > b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> > index ad73e5855580..8841c447d0e2 100644
> > --- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> > +++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
> > @@ -103,7 +103,7 @@ static void
> > amdgpu_dm_crtc_notify_ta_to_read(struct work_struct *work)  {
> >         struct secure_display_context *secure_display_ctx;
> >         struct psp_context *psp;
> > -       struct securedisplay_cmd *securedisplay_cmd;
> > +       struct ta_securedisplay_cmd *securedisplay_cmd;
> >         struct drm_crtc *crtc;
> >         struct dc_stream_state *stream;
> >         uint8_t phy_inst;
> > --
> > 2.39.0
> >

[-- Attachment #2: 0001-drm-amdgpu-update-ta_secureDisplay_if.h-to-v27.00.00.patch --]
[-- Type: application/octet-stream, Size: 6597 bytes --]

From 1d31a25c2ba77d57de6ce8c7cd01bff5b3ed578e Mon Sep 17 00:00:00 2001
From: Aaron Liu <aaron.liu@amd.com>
Date: Wed, 4 Jan 2023 09:18:06 +0800
Subject: [PATCH] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08

1. Rename securedisplay_cmd to ta_securedisplay_cmd.
2. Rename ta_securedisplay_max_phy to ta_securedisplay_phy_ID.
3. update securedisplay_cmd to ta_securedisplay_cmd

Signed-off-by: Aaron Liu <aaron.liu@amd.com>
Signed-off-by: Shane Xiao <shane.xiao@amd.com>
Reviewed-by: Alan Liu <HaoPing.Liu@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c       |  2 +-
 .../gpu/drm/amd/amdgpu/amdgpu_securedisplay.c |  8 +++----
 .../gpu/drm/amd/amdgpu/amdgpu_securedisplay.h |  2 +-
 .../gpu/drm/amd/amdgpu/ta_secureDisplay_if.h  | 24 +++++++++----------
 .../drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c |  2 +-
 5 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
index 0706afb11577..2bebda7de604 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_psp.c
@@ -1907,7 +1907,7 @@ int psp_rap_invoke(struct psp_context *psp, uint32_t ta_cmd_id, enum ta_rap_stat
 static int psp_securedisplay_initialize(struct psp_context *psp)
 {
 	int ret;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 
 	/*
 	 * TODO: bypass the initialize in sriov for now
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
index 2c1d82fc4c34..8ed0e073656f 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.c
@@ -77,11 +77,11 @@ void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 	}
 }
 
-void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
 	enum ta_securedisplay_command command_id)
 {
-	*cmd = (struct securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
-	memset(*cmd, 0, sizeof(struct securedisplay_cmd));
+	*cmd = (struct ta_securedisplay_cmd *)psp->securedisplay_context.context.mem_context.shared_buf;
+	memset(*cmd, 0, sizeof(struct ta_securedisplay_cmd));
 	(*cmd)->status = TA_SECUREDISPLAY_STATUS__GENERIC_FAILURE;
 	(*cmd)->cmd_id = command_id;
 }
@@ -93,7 +93,7 @@ static ssize_t amdgpu_securedisplay_debugfs_write(struct file *f, const char __u
 {
 	struct amdgpu_device *adev = (struct amdgpu_device *)file_inode(f)->i_private;
 	struct psp_context *psp = &adev->psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_device *dev = adev_to_drm(adev);
 	uint32_t phy_id;
 	uint32_t op;
diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
index fe98574748f4..456ad68ed4b2 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_securedisplay.h
@@ -30,7 +30,7 @@
 void amdgpu_securedisplay_debugfs_init(struct amdgpu_device *adev);
 void psp_securedisplay_parse_resp_status(struct psp_context *psp,
 		enum ta_securedisplay_status status);
-void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct securedisplay_cmd **cmd,
+void psp_prep_securedisplay_cmd_buf(struct psp_context *psp, struct ta_securedisplay_cmd **cmd,
 		enum ta_securedisplay_command command_id);
 
 #endif
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
index ad73e5855580..8841c447d0e2 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_crc.c
@@ -103,7 +103,7 @@ static void amdgpu_dm_crtc_notify_ta_to_read(struct work_struct *work)
 {
 	struct secure_display_context *secure_display_ctx;
 	struct psp_context *psp;
-	struct securedisplay_cmd *securedisplay_cmd;
+	struct ta_securedisplay_cmd *securedisplay_cmd;
 	struct drm_crtc *crtc;
 	struct dc_stream_state *stream;
 	uint8_t phy_inst;
diff --git a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
index cf8ff064dc72..00d8bdb8254f 100644
--- a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
+++ b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
@@ -55,10 +55,10 @@ enum ta_securedisplay_status {
 	TA_SECUREDISPLAY_STATUS__MAX                     = 0x7FFFFFFF,/* Maximum Value for status*/
 };
 
-/** @enum ta_securedisplay_max_phy
+/** @enum ta_securedisplay_phy_ID
  *    Physical ID number to use for reading corresponding DIO Scratch register for ROI
  */
-enum  ta_securedisplay_max_phy {
+enum  ta_securedisplay_phy_ID {
 	TA_SECUREDISPLAY_PHY0                           = 0,
 	TA_SECUREDISPLAY_PHY1                           = 1,
 	TA_SECUREDISPLAY_PHY2                           = 2,
@@ -139,16 +139,16 @@ union ta_securedisplay_cmd_output {
 	uint32_t                                           reserved[4];
 };
 
-/** @struct securedisplay_cmd
- *    Secure Display Command which is shared buffer memory
- */
-struct securedisplay_cmd {
-	uint32_t                             cmd_id;                    /* +0  Bytes Command ID */
-	enum ta_securedisplay_status         status;     /* +4  Bytes Status of Secure Display TA */
-	uint32_t                             reserved[2];               /* +8  Bytes Reserved */
-	union ta_securedisplay_cmd_input     securedisplay_in_message;  /* +16 Bytes Input Buffer */
-	union ta_securedisplay_cmd_output    securedisplay_out_message;/* +32 Bytes Output Buffer */
-	/**@note Total 48 Bytes */
+/** @struct ta_securedisplay_cmd
+*    Secure display command which is shared buffer memory
+*/
+struct ta_securedisplay_cmd {
+    uint32_t                                           cmd_id;                         /**< +0  Bytes Command ID */
+    enum ta_securedisplay_status                       status;                         /**< +4  Bytes Status code returned by the secure display TA */
+    uint32_t                                           reserved[2];                    /**< +8  Bytes Reserved */
+    union ta_securedisplay_cmd_input                   securedisplay_in_message;       /**< +16 Bytes Command input buffer */
+    union ta_securedisplay_cmd_output                  securedisplay_out_message;      /**< +32 Bytes Command output buffer */
+    /**@note Total 48 Bytes */
 };
 
 #endif   //_TA_SECUREDISPLAY_IF_H
-- 
2.39.0


^ permalink raw reply related	[flat|nested] 6+ messages in thread

* RE: [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08
  2023-01-05  1:04 [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Aaron Liu
  2023-01-05  1:04 ` [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd Aaron Liu
@ 2023-01-05  1:38 ` Liu, HaoPing (Alan)
  1 sibling, 0 replies; 6+ messages in thread
From: Liu, HaoPing (Alan) @ 2023-01-05  1:38 UTC (permalink / raw)
  To: Liu, Aaron, amd-gfx; +Cc: Deucher, Alexander, Xiao, Shane

[AMD Official Use Only - General]

Reviewed-by: Alan Liu <HaoPing.Liu@amd.com>

-----Original Message-----
From: Liu, Aaron <Aaron.Liu@amd.com> 
Sent: Thursday, January 5, 2023 9:04 AM
To: amd-gfx@lists.freedesktop.org
Cc: Liu, HaoPing (Alan) <HaoPing.Liu@amd.com>; Deucher, Alexander <Alexander.Deucher@amd.com>; Xiao, Shane <shane.xiao@amd.com>; Liu, Aaron <Aaron.Liu@amd.com>
Subject: [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08

1. Rename securedisplay_cmd to ta_securedisplay_cmd.
2. Rename ta_securedisplay_max_phy to ta_securedisplay_phy_ID.

Signed-off-by: Aaron Liu <aaron.liu@amd.com>
Signed-off-by: Shane Xiao <shane.xiao@amd.com>
---
 .../gpu/drm/amd/amdgpu/ta_secureDisplay_if.h  | 24 +++++++++----------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
index cf8ff064dc72..00d8bdb8254f 100644
--- a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
+++ b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
@@ -55,10 +55,10 @@ enum ta_securedisplay_status {
 	TA_SECUREDISPLAY_STATUS__MAX                     = 0x7FFFFFFF,/* Maximum Value for status*/
 };
 
-/** @enum ta_securedisplay_max_phy
+/** @enum ta_securedisplay_phy_ID
  *    Physical ID number to use for reading corresponding DIO Scratch register for ROI
  */
-enum  ta_securedisplay_max_phy {
+enum  ta_securedisplay_phy_ID {
 	TA_SECUREDISPLAY_PHY0                           = 0,
 	TA_SECUREDISPLAY_PHY1                           = 1,
 	TA_SECUREDISPLAY_PHY2                           = 2,
@@ -139,16 +139,16 @@ union ta_securedisplay_cmd_output {
 	uint32_t                                           reserved[4];
 };
 
-/** @struct securedisplay_cmd
- *    Secure Display Command which is shared buffer memory
- */
-struct securedisplay_cmd {
-	uint32_t                             cmd_id;                    /* +0  Bytes Command ID */
-	enum ta_securedisplay_status         status;     /* +4  Bytes Status of Secure Display TA */
-	uint32_t                             reserved[2];               /* +8  Bytes Reserved */
-	union ta_securedisplay_cmd_input     securedisplay_in_message;  /* +16 Bytes Input Buffer */
-	union ta_securedisplay_cmd_output    securedisplay_out_message;/* +32 Bytes Output Buffer */
-	/**@note Total 48 Bytes */
+/** @struct ta_securedisplay_cmd
+*    Secure display command which is shared buffer memory
+*/
+struct ta_securedisplay_cmd {
+    uint32_t                                           cmd_id;                         /**< +0  Bytes Command ID */
+    enum ta_securedisplay_status                       status;                         /**< +4  Bytes Status code returned by the secure display TA */
+    uint32_t                                           reserved[2];                    /**< +8  Bytes Reserved */
+    union ta_securedisplay_cmd_input                   securedisplay_in_message;       /**< +16 Bytes Command input buffer */
+    union ta_securedisplay_cmd_output                  securedisplay_out_message;      /**< +32 Bytes Command output buffer */
+    /**@note Total 48 Bytes */
 };
 
 #endif   //_TA_SECUREDISPLAY_IF_H
diff --git a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
index cf8ff064dc72..00d8bdb8254f 100644
--- a/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
+++ b/drivers/gpu/drm/amd/amdgpu/ta_secureDisplay_if.h
@@ -55,10 +55,10 @@ enum ta_securedisplay_status {
 	TA_SECUREDISPLAY_STATUS__MAX                     = 0x7FFFFFFF,/* Maximum Value for status*/
 };
 
-/** @enum ta_securedisplay_max_phy
+/** @enum ta_securedisplay_phy_ID
  *    Physical ID number to use for reading corresponding DIO Scratch register for ROI
  */
-enum  ta_securedisplay_max_phy {
+enum  ta_securedisplay_phy_ID {
 	TA_SECUREDISPLAY_PHY0                           = 0,
 	TA_SECUREDISPLAY_PHY1                           = 1,
 	TA_SECUREDISPLAY_PHY2                           = 2,
@@ -139,16 +139,16 @@ union ta_securedisplay_cmd_output {
 	uint32_t                                           reserved[4];
 };
 
-/** @struct securedisplay_cmd
- *    Secure Display Command which is shared buffer memory
- */
-struct securedisplay_cmd {
-	uint32_t                             cmd_id;                    /* +0  Bytes Command ID */
-	enum ta_securedisplay_status         status;     /* +4  Bytes Status of Secure Display TA */
-	uint32_t                             reserved[2];               /* +8  Bytes Reserved */
-	union ta_securedisplay_cmd_input     securedisplay_in_message;  /* +16 Bytes Input Buffer */
-	union ta_securedisplay_cmd_output    securedisplay_out_message;/* +32 Bytes Output Buffer */
-	/**@note Total 48 Bytes */
+/** @struct ta_securedisplay_cmd
+*    Secure display command which is shared buffer memory
+*/
+struct ta_securedisplay_cmd {
+    uint32_t                                           cmd_id;                         /**< +0  Bytes Command ID */
+    enum ta_securedisplay_status                       status;                         /**< +4  Bytes Status code returned by the secure display TA */
+    uint32_t                                           reserved[2];                    /**< +8  Bytes Reserved */
+    union ta_securedisplay_cmd_input                   securedisplay_in_message;       /**< +16 Bytes Command input buffer */
+    union ta_securedisplay_cmd_output                  securedisplay_out_message;      /**< +32 Bytes Command output buffer */
+    /**@note Total 48 Bytes */
 };
 
 #endif   //_TA_SECUREDISPLAY_IF_H
-- 
2.39.0


^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2023-01-05  4:59 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2023-01-05  1:04 [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Aaron Liu
2023-01-05  1:04 ` [PATCH 2/2] drm/amd: update securedisplay_cmd to ta_securedisplay_cmd Aaron Liu
2023-01-05  1:38   ` Liu, HaoPing (Alan)
2023-01-05  3:27   ` Alex Deucher
2023-01-05  4:59     ` Liu, Aaron
2023-01-05  1:38 ` [PATCH 1/2] drm/amdgpu: update ta_secureDisplay_if.h to v27.00.00.08 Liu, HaoPing (Alan)

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.